@@ -1,4 +1,3 @@
-import warnings
 from typing import Optional, Any, List, Sequence, Dict
 
 from pydantic import BaseModel
@@ -17,14 +16,13 @@ class SearchClient(NamespacedClient):
 
     api_prefix = '/api/search'
 
-    def search(self, index: str) -> 'DataIndex':
+    def search(self, index: str) -> 'IndexedQuery':
         """
         指定索引
 
         :param index: index名称
         """
-        warnings.warn('"search" is deprecated, use "index" instead', DeprecationWarning)
-        return DataIndex(index, self)
+        return IndexedQuery(index, self)
 
     def index(self, index: str) -> 'DataIndex':
         """
@@ -35,21 +33,6 @@ class SearchClient(NamespacedClient):
         return DataIndex(index, self)
 
 
-class IndexedQuery:
-    """
-    构建面向index的查询
-    """
-
-    def __init__(self, index: str, client: SearchClient):
-        self._index = index
-        self._client = client
-
-        self._queries: List[NamedClause] = []
-        self._filters: List[NamedClause] = []
-        self._page = None
-        self._size = None
-
-
 class Response:
     def __init__(self, data: dict):
         self.response = data
@@ -125,11 +108,31 @@ class DataIndex:
         read_json_data(
             self._client.session.put(
                 f'{self._client.api_prefix}/{self._index}/{id}',
-                data=_json.dumps(
-                    {
-                        'data': data,
+                data=_json.dumps({
+                    'data': data,
+                }).encode(),
+                headers={
+                    'content-type': _json.mimetype,
+                },
+            )
+        )
+
+    def update(self, id: str, data: str = None):
+        """
+        更新数据的指定字段
+
+        :param id: 数据ID
+        :param data: 更新的数据内容
+        """
+
+        read_json_data(
+            self._client.session.put(
+                f'{self._client.api_prefix}/{self._index}/update/{id}',
+                data=_json.dumps({
+                    'body': {
+                        'doc': data,
                     },
-                ).encode(),
+                }).encode(),
                 headers={
                     'content-type': _json.mimetype,
                 },
@@ -153,11 +156,9 @@ class DataIndex:
         data = read_json_data(
             self._client.session.post(
                 f'{self._client.api_prefix}/{self._index}/search-by-dsl',
-                data=_json.dumps(
-                    {
-                        'body': query_body,
-                    }
-                ).encode(),
+                data=_json.dumps({
+                    'body': query_body,
+                }).encode(),
                 headers={
                     'content-type': _json.mimetype,
                 },
@@ -169,11 +170,9 @@ class DataIndex:
         data = read_json_data(
             self._client.session.post(
                 f'{self._client.api_prefix}/{self._index}/count-by-dsl',
-                data=_json.dumps(
-                    {
-                        'body': query_body,
-                    },
-                ).encode(),
+                data=_json.dumps({
+                    'body': query_body,
+                }).encode(),
                 headers={
                     'content-type': _json.mimetype,
                 },
@@ -300,11 +299,7 @@ class NamedClause(BaseModel):
                 })
             else:
                 for i in self.value:
-                    must.append({
-                        'match_phrase': {
-                            self.name: i,
-                        }
-                    })
+                    must.append(self._match_phrase(self.name, i))
         elif self.type == ClauseType.IS_NOT:
             assert isinstance(self.value, Sequence)
             if self.name is None:
@@ -315,11 +310,7 @@ class NamedClause(BaseModel):
                 })
             else:
                 for i in self.value:
-                    must_not.append({
-                        'match_phrase': {
-                            self.name: i,
-                        }
-                    })
+                    must_not.append(self._match_phrase(self.name, i))
         elif self.type == ClauseType.IS_ONE_OF:
             assert isinstance(self.value, Sequence)
             b = BoolQuery()
@@ -332,11 +323,7 @@ class NamedClause(BaseModel):
                     })
             else:
                 for v in self.value:
-                    b.should.append({
-                        'match_phrase': {
-                            self.name: v
-                        }
-                    })
+                    b.should.append(self._match_phrase(self.name, v))
             must.append({
                 'bool': b.dict(),
             })
@@ -360,18 +347,10 @@ class NamedClause(BaseModel):
                         must_not.append(_q)
         elif self.type == ClauseType.EXISTS:
             if self.name is not None:
-                must.append({
-                    'exists': {
-                        'field': self.name
-                    }
-                })
+                must.append(self._exists(self.name))
         elif self.type == ClauseType.DOES_NOT_EXIST:
             if self.name is not None:
-                must_not.append({
-                    'exists': {
-                        'field': self.name
-                    }
-                })
+                must_not.append(self._exists(self.name))
         elif self.type == ClauseType.MATCH:
             assert isinstance(self.value, Sequence)
             if self.name is None:
@@ -382,11 +361,48 @@ class NamedClause(BaseModel):
                 })
             else:
                 for i in self.value:
-                    must.append({
-                        'match': {
-                            self.name: i,
-                        }
-                    })
+                    must.append(self._match(self.name, i))
+
+    @staticmethod
+    def _match_phrase(name: str, value: Any) -> dict:
+        if ',' in name:
+            s = name.split(',')
+            return {
+                "multi_match": {
+                    "type": "phrase",
+                    "query": value,
+                    "fields": [i.strip() for i in s]
+                }
+            }
+        return {
+            'match_phrase': {
+                name: value
+            }
+        }
+
+    @staticmethod
+    def _match(name: str, value: Any) -> dict:
+        if ',' in name:
+            s = name.split(',')
+            return {
+                "multi_match": {
+                    "query": value,
+                    "fields": [i.strip() for i in s]
+                }
+            }
+        return {
+            'match': {
+                name: value,
+            }
+        }
+
+    @staticmethod
+    def _exists(name: str) -> dict:
+        return {
+            'exists': {
+                'field': name
+            }
+        }
 
 
 class QueryBuilder:
